# torlib

torlib is an open source Python utility package that can help in many scenarios :D

[![Package Version](https://img.shields.io/pypi/v/torlib.svg)](https://pypi.python.org/pypi/torlib/)
[![Python 3.6](https://img.shields.io/badge/python-3.6-blue.svg)](https://www.python.org/downloads/release/python-360/)



# Installation

This package can be installed from [PyPi](https://pypi.python.org/pypi/ChatterBot) by running:

```
pip install torlib
```

# Documentation

You can view the [documentation](https://noppadol-assava.github.io/torlib/) for torlib.

To build the documentation locally, you can run the following command on your terminal ([Sphinx](http://www.sphinx-doc.org/) is required):

```
sphinx-build -b html docs/ docs/_build/ -D language="en"
```

# Features

* [Crawler](https://noppadol-assava.github.io/torlib/en/master/crawler.html)

# Changelog

See release notes for changelog https://github.com/noppadol-assava/torlib/releases


# License

torlib is licensed under the [MIT License](https://opensource.org/licenses/MIT).